#ifndef NT2_INCLUDE_CONSTANTS_ZERO_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_ZERO_HPP_INCLUDED

#include <nt2/constant/include/constants/zero.hpp>

#endif
